File vbox-default-os-type.diff of Package virtualbox

--- src/VBox/Frontends/VirtualBox/src/widgets/VBoxOSTypeSelectorWidget.cpp.orig	2010-11-10 21:27:23.000000000 +0100
+++ src/VBox/Frontends/VirtualBox/src/widgets/VBoxOSTypeSelectorWidget.cpp	2010-11-10 21:27:53.000000000 +0100
@@ -199,10 +199,10 @@
         if (xpIndex != -1)
             mCbType->setCurrentIndex (xpIndex);
     }
     /* Or select Ubuntu item for Linux family as default */
     else if (familyId == "Linux")
     {
-        int ubIndex = mCbType->findData ("Ubuntu", RoleTypeID);
+        int ubIndex = mCbType->findData ("OpenSUSE", RoleTypeID);
         if (ubIndex != -1)
             mCbType->setCurrentIndex (ubIndex);
     }
@@ -199,10 +199,10 @@
             mCbType->setCurrentIndex (xpIndex);
     }
-    /* Or select Ubuntu item for Linux family as default */
+    /* Or select openSUSE item for Linux family as default */
     else if (familyId == "Linux")
     {
openSUSE Build Service is sponsored by